@@ -375,29 +375,21 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
 
   function handleMouseDownRotate(event) {
 
-    //console.log( 'handleMouseDownRotate' );
-
     rotateStart.set(event.clientX, event.clientY);
   }
 
   function handleMouseDownDolly(event) {
 
-    //console.log( 'handleMouseDownDolly' );
-
     dollyStart.set(event.clientX, event.clientY);
   }
 
   function handleMouseDownPan(event) {
 
-    //console.log( 'handleMouseDownPan' );
-
     panStart.set(event.clientX, event.clientY);
   }
 
   function handleMouseMoveRotate(event) {
 
-    //console.log( 'handleMouseMoveRotate' );
-
     rotateEnd.set(event.clientX, event.clientY);
     rotateDelta.subVectors(rotateEnd, rotateStart);
 
@@ -416,8 +408,6 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
 
   function handleMouseMoveDolly(event) {
 
-    //console.log( 'handleMouseMoveDolly' );
-
     dollyEnd.set(event.clientX, event.clientY);
 
     dollyDelta.subVectors(dollyEnd, dollyStart);
@@ -437,8 +427,6 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
 
   function handleMouseMovePan(event) {
 
-    //console.log( 'handleMouseMovePan' );
-
     panEnd.set(event.clientX, event.clientY);
 
     panDelta.subVectors(panEnd, panStart);
@@ -450,16 +438,10 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
     scope.update();
   }
 
-  function handleMouseUp(event) {
-
-    //console.log( 'handleMouseUp' );
-
-  }
+  function handleMouseUp(event) {}
 
   function handleMouseWheel(event) {
 
-    //console.log( 'handleMouseWheel' );
-
     if (event.deltaY < 0) {
 
       dollyOut(getZoomScale());
@@ -473,8 +455,6 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
 
   function handleKeyDown(event) {
 
-    //console.log( 'handleKeyDown' );
-
     switch (event.keyCode) {
 
       case scope.keys.UP:
@@ -501,16 +481,10 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
   }
 
   function handleTouchStartRotate(event) {
-
-    //console.log( 'handleTouchStartRotate' );
-
     rotateStart.set(event.touches[0].pageX, event.touches[0].pageY);
   }
 
   function handleTouchStartDolly(event) {
-
-    //console.log( 'handleTouchStartDolly' );
-
     var dx = event.touches[0].pageX - event.touches[1].pageX;
     var dy = event.touches[0].pageY - event.touches[1].pageY;
 
@@ -520,16 +494,10 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
   }
 
   function handleTouchStartPan(event) {
-
-    //console.log( 'handleTouchStartPan' );
-
     panStart.set(event.touches[0].pageX, event.touches[0].pageY);
   }
 
   function handleTouchMoveRotate(event) {
-
-    //console.log( 'handleTouchMoveRotate' );
-
     rotateEnd.set(event.touches[0].pageX, event.touches[0].pageY);
     rotateDelta.subVectors(rotateEnd, rotateStart);
 
@@ -547,9 +515,6 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
   }
 
   function handleTouchMoveDolly(event) {
-
-    //console.log( 'handleTouchMoveDolly' );
-
     var dx = event.touches[0].pageX - event.touches[1].pageX;
     var dy = event.touches[0].pageY - event.touches[1].pageY;
 
@@ -573,9 +538,6 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
   }
 
   function handleTouchMovePan(event) {
-
-    //console.log( 'handleTouchMovePan' );
-
     panEnd.set(event.touches[0].pageX, event.touches[0].pageY);
 
     panDelta.subVectors(panEnd, panStart);
@@ -589,16 +551,15 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
 
   function handleTouchEnd(event) {}
 
-  //console.log( 'handleTouchEnd' );
-
   //
   // event handlers - FSM: listen for events and reset state
   //
 
   function onMouseDown(event) {
-
     if (scope.enabled === false) return;
 
+    event.preventDefault();
+
     if (event.button === scope.mouseButtons.ORBIT) {
 
       if (scope.enableRotate === false) return;
@@ -793,11 +754,13 @@ module.exports = OrbitControls = function OrbitControls(object, domElement) {
     state = STATE.NONE;
   }
 
-  function onContextMenu(event) {}
+  function onContextMenu(event) {
+    event.preventDefault();
+  }
 
-  scope.domElement.addEventListener('contextmenu', onContextMenu, { passive: true });
+  scope.domElement.addEventListener('contextmenu', onContextMenu, false);
 
-  scope.domElement.addEventListener('mousedown', onMouseDown, { passive: true });
+  scope.domElement.addEventListener('mousedown', onMouseDown, false);
   scope.domElement.addEventListener('wheel', onMouseWheel, { passive: true });
 
   scope.domElement.addEventListener('touchstart', onTouchStart, { passive: true });
