@@ -3,7 +3,7 @@ import { Map, List } from 'immutable';
 import { sceneSnapElements } from '../utils/snap-scene';
 import { nearestSnap } from '../utils/snap';
 import { detectAndUpdateAreas, removeLine, addLineAvoidingIntersections, mergeEqualsVertices } from '../utils/layer-operations';
-import { orderVertices, pointsDistance } from "../utils/geometry";
+import { orderVertices, pointsDistance, samePoints } from "../utils/geometry";
 
 export default function (state, action) {
   switch (action.type) {
@@ -110,8 +110,12 @@ function endDraggingVertex(state, x, y) {
             oldHoles.push({ hole: hole, offsetPosition: { x: xp, y: yp } });
           });
 
+          mergeEqualsVertices(layer, vertexID);
           removeLine(layer, lineID);
-          addLineAvoidingIntersections(layer, line.type, oldVertex.x, oldVertex.y, vertex.x, vertex.y, catalog, line.properties, oldHoles);
+
+          if (!samePoints(oldVertex, vertex)) {
+            addLineAvoidingIntersections(layer, line.type, oldVertex.x, oldVertex.y, vertex.x, vertex.y, catalog, line.properties, oldHoles);
+          }
         }
       });
 
