@@ -8,7 +8,7 @@ var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = [
  *  @return {number}
  */
 import { toFixedFloat, fAbs } from './math.js';
-import { EPSILON } from "../constants";
+import { EPSILON } from '../constants';
 
 export function compareVertices(v0, v1) {
   return v0.x === v1.x ? v0.y - v1.y : v0.x - v1.x;
@@ -52,10 +52,7 @@ export function verticalLine(x) {
 }
 
 export function linePassingThroughTwoPoints(x1, y1, x2, y2) {
-  // (x2 - x1)(y - y1) = (y2 - y1)(x - x1)
-  // (y1 - y2)x + (x2 - x1)y + (y2x1 - x2y1) = 0
-
-  if (x1 === x2 && y1 == y2) throw new Error("Geometry error");
+  if (x1 === x2 && y1 == y2) throw new Error('Geometry error');
   if (x1 === x2) return verticalLine(x);
   if (y1 === y2) return horizontalLine(y1);
 
@@ -124,12 +121,12 @@ export function intersectionFromTwoLineSegment(p1, p2, p3, p4) {
           lineDX = _sort2[1];
 
       if (lineSX[1].x === lineDX[0].x) {
-        return { type: lineDX[0].y <= lineSX[1].y ? "colinear" : "none" };
+        return { type: lineDX[0].y <= lineSX[1].y ? 'colinear' : 'none' };
       } else {
-        return { type: lineDX[0].x <= lineSX[1].x ? "colinear" : "none" };
+        return { type: lineDX[0].x <= lineSX[1].x ? 'colinear' : 'none' };
       }
     }
-    return { type: "parallel" };
+    return { type: 'parallel' };
   }
 
   var uA = numA / denom;
@@ -140,10 +137,10 @@ export function intersectionFromTwoLineSegment(p1, p2, p3, p4) {
       x: x1 + uA * (x2 - x1),
       y: y1 + uA * (y2 - y1)
     };
-    return { type: "intersecting", point: point };
+    return { type: 'intersecting', point: point };
   }
 
-  return { type: "none" };
+  return { type: 'none' };
 }
 
 export function distancePointFromLineSegment(x1, y1, x2, y2, xp, yp) {
