@@ -1,14 +1,15 @@
-import React, {Component} from 'react';
+import React, { Component } from 'react';
 import PropTypes from 'prop-types';
 import If from '../../utils/react-if';
 import FooterToggleButton from './footer-toggle-button';
 import FooterContentButton from './footer-content-button';
-import {SNAP_POINT, SNAP_LINE, SNAP_SEGMENT, SNAP_GRID, SNAP_MASK} from '../../utils/snap';
-import {MODE_SNAPPING} from '../../constants';
+import { SNAP_POINT, SNAP_LINE, SNAP_SEGMENT, SNAP_GRID, SNAP_MASK } from '../../utils/snap';
+import { MODE_SNAPPING } from '../../constants';
 import * as SharedStyle from '../../shared-style';
 import IconClose from 'react-icons/lib/fa/close';
 import MdAddCircle from 'react-icons/lib/md/add-circle';
 import MdWarning from 'react-icons/lib/md/warning';
+import { VERSION } from '../../version';
 
 const footerBarStyle = {
   position: 'absolute',
@@ -57,28 +58,28 @@ export default class FooterBar extends Component {
 
   render() {
 
-    let {x, y} = this.props.state.get('mouse').toJS();
+    let { x, y } = this.props.state.get('mouse').toJS();
     let zoom = this.props.state.get('zoom');
     let mode = this.props.state.get('mode');
 
     let errors = this.props.state.get('errors').toArray();
-    let errorsJsx = errors.map((err,ind) =>
-      <div key={ind} style={{borderBottom:'1px solid #555', lineHeight:'1.5em'}}>[ { (new Date(err.date)).toLocaleString() } ] {err.error}</div>
+    let errorsJsx = errors.map((err, ind) =>
+      <div key={ind} style={{ borderBottom: '1px solid #555', lineHeight: '1.5em' }}>[ {(new Date(err.date)).toLocaleString()} ] {err.error}</div>
     );
-    let errorLableStyle = errors.length ? {color:SharedStyle.MATERIAL_COLORS[500].red} : {};
-    let errorIconStyle = errors.length ? {transform:'rotate(45deg)',color:SharedStyle.MATERIAL_COLORS[500].red} : {transform:'rotate(45deg)'};
+    let errorLableStyle = errors.length ? { color: SharedStyle.MATERIAL_COLORS[500].red } : {};
+    let errorIconStyle = errors.length ? { transform: 'rotate(45deg)', color: SharedStyle.MATERIAL_COLORS[500].red } : { transform: 'rotate(45deg)' };
 
     let warnings = this.props.state.get('warnings').toArray();
-    let warningsJsx = warnings.map((warn,ind) =>
-      <div key={ind} style={{borderBottom:'1px solid #555', lineHeight:'1.5em'}}>[ { (new Date(warn.date)).toLocaleString() } ] {warn.warning}</div>
+    let warningsJsx = warnings.map((warn, ind) =>
+      <div key={ind} style={{ borderBottom: '1px solid #555', lineHeight: '1.5em' }}>[ {(new Date(warn.date)).toLocaleString()} ] {warn.warning}</div>
     );
-    let warningLableStyle = warnings.length ? {color:SharedStyle.MATERIAL_COLORS[500].yellow} : {};
+    let warningLableStyle = warnings.length ? { color: SharedStyle.MATERIAL_COLORS[500].yellow } : {};
     let warningIconStyle = warningLableStyle;
 
     let updateSnapMask = (val) => this.context.projectActions.toggleSnap(this.props.state.snapMask.merge(val));
 
     return (
-      <div style={{...footerBarStyle, width: this.props.width, height: this.props.height}}>
+      <div style={{ ...footerBarStyle, width: this.props.width, height: this.props.height }}>
 
         <If condition={MODE_SNAPPING.includes(mode)}>
           <div style={leftTextStyle}>
@@ -91,32 +92,32 @@ export default class FooterBar extends Component {
           <div style={leftTextStyle}>
             <FooterToggleButton
               state={this.state}
-              toggleOn={() => { updateSnapMask({SNAP_POINT: true}); }}
-              toggleOff={() => { updateSnapMask({SNAP_POINT: false}); }}
+              toggleOn={() => { updateSnapMask({ SNAP_POINT: true }); }}
+              toggleOff={() => { updateSnapMask({ SNAP_POINT: false }); }}
               text="Snap PT"
               toggleState={this.props.state.snapMask.get(SNAP_POINT)}
               title={this.context.translator.t('Snap to Point')}
             />
             <FooterToggleButton
               state={this.state}
-              toggleOn={() => { updateSnapMask({SNAP_LINE: true}); }}
-              toggleOff={() => { updateSnapMask({SNAP_LINE: false}); }}
+              toggleOn={() => { updateSnapMask({ SNAP_LINE: true }); }}
+              toggleOff={() => { updateSnapMask({ SNAP_LINE: false }); }}
               text="Snap LN"
               toggleState={this.props.state.snapMask.get(SNAP_LINE)}
               title={this.context.translator.t('Snap to Line')}
             />
             <FooterToggleButton
               state={this.state}
-              toggleOn={() => { updateSnapMask({SNAP_SEGMENT: true}); }}
-              toggleOff={() => { updateSnapMask({SNAP_SEGMENT: false}); }}
+              toggleOn={() => { updateSnapMask({ SNAP_SEGMENT: true }); }}
+              toggleOff={() => { updateSnapMask({ SNAP_SEGMENT: false }); }}
               text="Snap SEG"
               toggleState={this.props.state.snapMask.get(SNAP_SEGMENT)}
               title={this.context.translator.t('Snap to Segment')}
             />
             <FooterToggleButton
               state={this.state}
-              toggleOn={() => { updateSnapMask({SNAP_GRID: true}); }}
-              toggleOff={() => { updateSnapMask({SNAP_GRID: false}); }}
+              toggleOn={() => { updateSnapMask({ SNAP_GRID: true }); }}
+              toggleOff={() => { updateSnapMask({ SNAP_GRID: false }); }}
               text="Snap GRD"
               toggleState={this.props.state.snapMask.get(SNAP_GRID)}
               title={this.context.translator.t('Snap to Grid')}
@@ -124,9 +125,18 @@ export default class FooterBar extends Component {
           </div>
         </If>
 
-        {this.props.footerbarComponents.map((Component, index) => <Component state={state} key={index}/>)}
+        {this.props.footerbarComponents.map((Component, index) => <Component state={state} key={index} />)}
 
-        {this.props.softwareSignature ? <div style={rightTextStyle}>{this.props.softwareSignature}</div> : null}
+        {
+          this.props.softwareSignature ?
+            <div
+              style={rightTextStyle}
+              title={this.props.softwareSignature + (this.props.softwareSignature.includes('React-Planner') ? '' : ` using React-Planner ${VERSION}`)}
+            >
+              {this.props.softwareSignature}
+            </div>
+            : null
+        }
 
         <div style={rightTextStyle}>
           <FooterContentButton
